@@ -6,8 +6,7 @@ use 5.008001;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build or find libtool
-our $VERSION = '0.10_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '0.01'; # VERSION
 
 
 
@@ -29,7 +28,7 @@ Alien::libtool - Build or find libtool
 
 =head1 VERSION
 
-version 0.10_01
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -38,7 +37,7 @@ In your script or module:
  use Alien::libtool;
  use Env qw( @PATH );
  
- unshift @PATH, Alien::libtool->bin_dir;
+ unshift @ENV, Alien::libtool->bin_dir;
 
 =head1 DESCRIPTION
 
@@ -55,11 +54,7 @@ L<Alien>, L<Alien::Base>, L<Alien::Build::Manual::AlienUser>
 
 =head1 AUTHOR
 
-Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Zaki Mughal (zmughal, sivoais)
+Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
